@@ -2,6 +2,7 @@
 
 /* 
  * Copyright (C) 2001 Havoc Pennington
+ * Copyright (C) 2003 Red Hat, Inc.
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -39,6 +40,7 @@ meta_window_ensure_frame (MetaWindow *window)
 {
   MetaFrame *frame;
   XSetWindowAttributes attrs;
+  Visual *visual;
   
   if (window->frame)
     return;
@@ -78,10 +80,16 @@ meta_window_ensure_frame (MetaWindow *window)
    * visual as the client.
    */
 
+  visual = 0;
+  /* XXX special case for depth 32 windows (assumed to be ARGB) */
+  if (window->depth == 32)
+    visual = window->xvisual;  
+
   frame->xwindow = meta_ui_create_frame_window (window->screen->ui,
-						window->display->xdisplay,
-						frame->rect.x,
-						frame->rect.y,
+                                                window->display->xdisplay,
+                                                visual,
+                                                frame->rect.x,
+                                                frame->rect.y,
 						frame->rect.width,
 						frame->rect.height,
 						frame->window->screen->number);
@@ -153,6 +161,8 @@ meta_window_destroy_frame (MetaWindow *window)
   if (window->frame == NULL)
     return;
 
+  meta_verbose ("Unframing window %s\n", window->desc);
+  
   frame = window->frame;
   
   meta_bell_notify_frame_destroy (frame);
